[![Pipeline](https://gitlab.dlr.de/qci-connect/partners/all/qciconnect-sdk/badges/develop/pipeline.svg)](https://gitlab.dlr.de/qci-connect/partners/all/qciconnect-sdk)

# QCI Connect SDK

This is a python package to interact with the [QCi Connect](http://qc-plat-pro.dlr.de/) platform of the [German Aerospace Center (DLR)](https://www.dlr.de/). 
It also allows to login to the platform, obtain a session token, submit quantum circuits for compilation and execution, and retrieve the results of the execution. 

## Quick start

The following steps provide a quick start on how to programmatically interact with the QCi Connect platform:

- Run `pip install qciconnect`
- Run `jupyter notebook` and navigate to _./examples/example_remote.ipynb_

